<?php
/**
 * Plugin Name: Nomos Toolkit
 * Plugin URI:  http://famithemes.com
 * Description: nomos toolkit for nomos theme. Currently supports the following theme functionality: shortcodes, CPT.
 * Version:     1.2.7
 * Author:      Famithemes
 * Author URI:  http://www.famithemes.com
 * License:     GNU/GPL v2 or later http://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: nomos-toolkit
 */

// Define path to this plugin file.
define( 'NOMOS_TOOLKIT_PATH', plugin_dir_path( __FILE__ ) );

// Define url to this plugin file.
define( 'NOMOS_TOOLKIT_URL', plugin_dir_url( __FILE__ ) );

// Include function plugins if not include.
if ( ! function_exists( 'is_plugin_active' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
}

/**
 * Load plugin textdomain.
 *
 * @since 1.0.0
 */
function nomos_toolkit_load_textdomain() {
	load_plugin_textdomain( 'nomos-toolkit', false, NOMOS_TOOLKIT_PATH . '/languages' );
}

add_action( 'init', 'nomos_toolkit_load_textdomain' );

// Add css and js for admin
function nomos_admin_register_scripts() {
	wp_enqueue_style( 'flexslider', plugins_url( '/assets/vendors/flexslider/flexslider.min.css', __FILE__ ) );
	wp_enqueue_style( 'nomos-toolkit-style', plugins_url( '/assets/css/admin.css', __FILE__ ) );
	wp_enqueue_script( 'nomos-toolkit-script', plugins_url( '/assets/js/admin.js', __FILE__ ), array( 'jquery' ), false, true );
}

add_action( 'admin_enqueue_scripts', 'nomos_admin_register_scripts' );

function nomos_toolkit_frontend_script() {
	wp_enqueue_script( 'flexslider', plugins_url( '/assets/vendors/flexslider/jquery.flexslider-min.js', __FILE__ ), array( 'jquery' ), false, true );
	wp_enqueue_script( 'nomos-toolkit-frontend-script', plugins_url( '/assets/js/shortcode.js', __FILE__ ), array( 'jquery' ), false, true );
	wp_localize_script( 'nomos-toolkit-frontend-script', 'nomos_ajax_frontend', array(
		                                                   'ajaxurl'  => admin_url( 'admin-ajax.php' ),
		                                                   'security' => wp_create_nonce( 'nomos_ajax_frontend' ),
	                                                   )
	);
}

add_action( 'wp_enqueue_scripts', 'nomos_toolkit_frontend_script' );

// Run shortcode in widget text
add_filter( 'widget_text', 'do_shortcode' );

// For WooCommerce
if ( is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
	include_once( NOMOS_TOOLKIT_PATH . '/includes/classes/woo-attributes-swatches/woo-term.php' );
	include_once( NOMOS_TOOLKIT_PATH . '/includes/classes/woo-attributes-swatches/woo-product-attribute-meta.php' );
	include_once( NOMOS_TOOLKIT_PATH . '/includes/shortcode.php' );
}

// Load the core class.
include_once( NOMOS_TOOLKIT_PATH . '/includes/classes/nomos-mapper/includes/core.php' );

// Instantiate an object of the core class.
Nomos_Mapper::initialize();

// Load functions
include_once( NOMOS_TOOLKIT_PATH . '/includes/functions.php' );

// Register custom shortcodes
include_once( NOMOS_TOOLKIT_PATH . '/includes/shortcode.php' );

// Register custom post types
include_once( NOMOS_TOOLKIT_PATH . '/includes/post-types.php' );

// Register init

if ( ! function_exists( 'nomos_toolkit_init' ) ) {
	function nomos_toolkit_init() {
		include_once( NOMOS_TOOLKIT_PATH . '/includes/init.php' );
	}
}

add_action( 'nomos_toolkit_init', 'nomos_toolkit_init' );

if ( ! function_exists( 'nomos_toolkit_install' ) ) {
	function nomos_toolkit_install() {
		do_action( 'nomos_toolkit_init' );
		
		if ( class_exists( 'PrdctfltrInit' ) && class_exists( 'WPBakeryShortCode' ) ) {
			include_once( NOMOS_TOOLKIT_PATH . '/includes/fami-pf-composer.php' );
			include_once( NOMOS_TOOLKIT_PATH . '/includes/shortcodes/fami-pf-shortcode.php' );
		}
	}
}
add_action( 'plugins_loaded', 'nomos_toolkit_install', 11 );

function nomos_toolkit_remove_type_attr( $tag, $handle ) {
	return preg_replace( "/type=['\"]text\/(javascript|css)['\"]/", '', $tag );
}

add_filter( 'style_loader_tag', 'nomos_toolkit_remove_type_attr', 99, 2 );
add_filter( 'script_loader_tag', 'nomos_toolkit_remove_type_attr', 99, 2 );
