<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}


if ( ! function_exists( 'nomos_x_trans' ) ) {
	/*
	 * For _x
	 */
	function nomos_x_trans( $text, $context, $domain = 'default' ) {
		return translate_with_gettext_context( $text, $context, $domain );
	}
}

if ( ! function_exists( 'nomos_ex_trans' ) ) {
	/*
	 * For _ex
	 */
	function nomos_ex_trans( $text, $context, $domain = 'default' ) {
		echo nomos_x_trans( $text, $context, $domain );
	}
}

if ( ! function_exists( 'nomos_n_trans' ) ) {
	// For _n
	function nomos_n_trans( $single, $plural, $number, $domain = 'default' ) {
		$translations = get_translations_for_domain( $domain );
		$translation  = $translations->translate_plural( $single, $plural, $number );
		
		/**
		 * Filters the singular or plural form of a string.
		 *
		 * @since 2.2.0
		 *
		 * @param string $translation Translated text.
		 * @param string $single      The text to be used if the number is singular.
		 * @param string $plural      The text to be used if the number is plural.
		 * @param string $number      The number to compare against to use either the singular or plural form.
		 * @param string $domain      Text domain. Unique identifier for retrieving translated strings.
		 */
		return apply_filters( 'ngettext', $translation, $single, $plural, $number, $domain );
	}
}

if ( ! function_exists( 'nomos_html_x_trans' ) ) {
	// For html_x
	function nomos_html_x_trans( $text, $context, $domain = 'default' ) {
		return esc_html( translate_with_gettext_context( $text, $context, $domain ) );
	}
}

if ( ! function_exists( 'nomos_translate_text' ) ) {
	/*
	 * Not esc string
	 * For __
	 */
	function nomos_translate_text( $text, $domain = 'default' ) {
		return translate( $text, $domain );
	}
}

if ( ! function_exists( 'nomos_translate_text_e' ) ) {
	/*
	 * For _e
	 */
	function nomos_translate_text_e( $text, $domain = 'default' ) {
		echo translate( $text, $domain );
	}
}

if ( ! function_exists( 'nomos_esc_text_html' ) ) {
	/*
	 * For esc_html__
	 */
	function nomos_esc_text_html( $text, $domain = 'default' ) {
		return esc_html( translate( $text, $domain ) );
	}
}

if ( ! function_exists( 'nomos_esc_text_html_e' ) ) {
	/*
	 * For esc_html_e
	 */
	function nomos_esc_text_html_e( $text, $domain = 'default' ) {
		echo esc_html( translate( $text, $domain ) );
	}
}

if ( ! function_exists( 'nomos_n' ) ) {
	/*
	 * For _n
	 */
	function nomos_n( $single, $plural, $number, $domain = 'default' ) {
		$translations = get_translations_for_domain( $domain );
		$translation  = $translations->translate_plural( $single, $plural, $number );
		
		/**
		 * Filters the singular or plural form of a string.
		 *
		 * @since 2.2.0
		 *
		 * @param string $translation Translated text.
		 * @param string $single      The text to be used if the number is singular.
		 * @param string $plural      The text to be used if the number is plural.
		 * @param string $number      The number to compare against to use either the singular or plural form.
		 * @param string $domain      Text domain. Unique identifier for retrieving translated strings.
		 */
		return apply_filters( 'ngettext', $translation, $single, $plural, $number, $domain );
	}
}

if ( ! function_exists( 'nomos_n_html' ) ) {
	/*
	 * Fami custom
	 */
	function nomos_n_html( $single, $plural, $number, $domain = 'default' ) {
		$translations = get_translations_for_domain( $domain );
		$translation  = $translations->translate_plural( $single, $plural, $number );
		
		/**
		 * Filters the singular or plural form of a string.
		 *
		 * @since 2.2.0
		 *
		 * @param string $translation Translated text.
		 * @param string $single      The text to be used if the number is singular.
		 * @param string $plural      The text to be used if the number is plural.
		 * @param string $number      The number to compare against to use either the singular or plural form.
		 * @param string $domain      Text domain. Unique identifier for retrieving translated strings.
		 */
		return nomos_esc_text_html( apply_filters( 'ngettext', $translation, $single, $plural, $number, $domain ) );
	}
}

if ( ! function_exists( 'nomos_nx' ) ) {
	/*
	 * For nx
	 */
	function nomos_nx( $single, $plural, $number, $context, $domain = 'default' ) {
		$translations = get_translations_for_domain( $domain );
		$translation  = $translations->translate_plural( $single, $plural, $number, $context );
		
		/**
		 * Filters the singular or plural form of a string with gettext context.
		 *
		 * @since 2.8.0
		 *
		 * @param string $translation Translated text.
		 * @param string $single      The text to be used if the number is singular.
		 * @param string $plural      The text to be used if the number is plural.
		 * @param string $number      The number to compare against to use either the singular or plural form.
		 * @param string $context     Context information for the translators.
		 * @param string $domain      Text domain. Unique identifier for retrieving translated strings.
		 */
		return apply_filters( 'ngettext_with_context', $translation, $single, $plural, $number, $context, $domain );
	}
}

if ( ! function_exists( 'nomos_nx_html' ) ) {
	/*
	 * For nx
	 */
	function nomos_nx_html( $single, $plural, $number, $context, $domain = 'default' ) {
		$translations = get_translations_for_domain( $domain );
		$translation  = $translations->translate_plural( $single, $plural, $number, $context );
		
		/**
		 * Filters the singular or plural form of a string with gettext context.
		 *
		 * @since 2.8.0
		 *
		 * @param string $translation Translated text.
		 * @param string $single      The text to be used if the number is singular.
		 * @param string $plural      The text to be used if the number is plural.
		 * @param string $number      The number to compare against to use either the singular or plural form.
		 * @param string $context     Context information for the translators.
		 * @param string $domain      Text domain. Unique identifier for retrieving translated strings.
		 */
		return nomos_esc_text_html( apply_filters( 'ngettext_with_context', $translation, $single, $plural, $number, $context, $domain ) );
	}
}

if (!function_exists('nomos_esc_attr_trans')) {
	/*
	 * For esc_attr__
	 */
	function nomos_esc_attr_trans( $text, $domain = 'default' ) {
		return esc_attr( translate( $text, $domain ) );
	}
}

if (!function_exists('nomos_esc_attr_trans_e')) {
	/*
	 * For esc_attr_e
	 */
	function nomos_esc_attr_trans_e( $text, $domain = 'default' ) {
		echo esc_attr( translate( $text, $domain ) );
	}
}
