<?php
if ( ! isset( $content_width ) ) {
	$content_width = 900;
}
if ( ! class_exists( 'Nomos_Functions' ) ) {
	class Nomos_Functions {
		/**
		 * Instance of the class.
		 *
		 * @since   1.0.0
		 *
		 * @var   object
		 */
		protected static $instance = null;
		
		/**
		 * Initialize the plugin by setting localization and loading public scripts
		 * and styles.
		 *
		 * @since    1.0.0
		 */
		public function __construct() {
			add_action( 'after_setup_theme', array( $this, 'nomos_settup' ) );
			add_action( 'widgets_init', array( $this, 'widgets_init' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );
			add_filter( 'get_default_comment_status', array( $this, 'open_default_comments_for_page' ), 10, 3 );
			add_filter( 'comment_form_fields', array( &$this, 'nomos_move_comment_field_to_bottom' ), 10, 3 );
			
			remove_action( 'wp_head', 'rest_output_link_wp_head' );
			remove_action( 'wp_head', 'wp_oembed_add_discovery_links' );
			remove_action( 'template_redirect', 'rest_output_link_header', 11 );
			
			$this->includes();
		}
		
		public function nomos_settup() {
			/*
			* Make theme available for translation.
			* Translations can be filed in the /languages/ directory.
			* If you're building a theme based on boutique, use a find and replace
			* to change 'nomos' to the name of your theme in all the template files
			*/
			load_theme_textdomain( 'nomos', get_template_directory() . '/languages' );
			add_theme_support( 'automatic-feed-links' );
			/*
			 * Let WordPress manage the document title.
			 * By adding theme support, we declare that this theme does not use a
			 * hard-coded <title> tag in the document head, and expect WordPress to
			 * provide it for us.
			 */
			add_theme_support( 'title-tag' );
			/*
			 * Enable support for Post Formats.
			 *
			 * See: https://codex.wordpress.org/Post_Formats
			 */
			add_theme_support( 'post-formats', array(
				'video',
				'gallery',
				'audio',
			) );
			/*
			 * Enable support for Post Thumbnails on posts and pages.
			 *
			 * See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
			 */
			add_theme_support( 'post-thumbnails' );
			add_theme_support( 'custom-header' );
			
			set_post_thumbnail_size( 825, 510, true );
			/*This theme uses wp_nav_menu() in two locations.*/
			register_nav_menus( array(
				                    'primary'       => nomos_esc_text_html( 'Primary Menu', 'nomos' ),
				                    'vertical_menu' => nomos_esc_text_html( 'Vertical Menu', 'nomos' ),
			                    )
			);
			/*
			 * Switch default core markup for search form, comment form, and comments
			 * to output valid HTML5.
			 */
			add_theme_support( 'html5', array(
				                          'search-form',
				                          'comment-form',
				                          'comment-list',
				                          'gallery',
				                          'caption',
			                          )
			);
			
			// Support Gutenberg
			// Add support for Block Styles.
			add_theme_support( 'wp-block-styles' );
			
			// Add support for full and wide align images.
			add_theme_support( 'align-wide' );
			
			// Add support for editor styles.
			add_theme_support( 'editor-styles' );
			
			// Enqueue editor styles.
			add_editor_style( 'style-editor.css' );
			
			// Add custom editor font sizes.
			add_theme_support(
				'editor-font-sizes',
				array(
					array(
						'name'      => esc_html__( 'Small', 'funiter' ),
						'shortName' => esc_html__( 'S', 'funiter' ),
						'size'      => 19.5,
						'slug'      => 'small',
					),
					array(
						'name'      => esc_html__( 'Normal', 'funiter' ),
						'shortName' => esc_html__( 'M', 'funiter' ),
						'size'      => 22,
						'slug'      => 'normal',
					),
					array(
						'name'      => esc_html__( 'Large', 'funiter' ),
						'shortName' => esc_html__( 'L', 'funiter' ),
						'size'      => 36.5,
						'slug'      => 'large',
					),
					array(
						'name'      => esc_html__( 'Huge', 'funiter' ),
						'shortName' => esc_html__( 'XL', 'funiter' ),
						'size'      => 49.5,
						'slug'      => 'huge',
					),
				)
			);
			
			// Editor color palette.
			add_theme_support(
				'editor-color-palette',
				array(
					array(
						'name'  => esc_html__( 'Primary', 'funiter' ),
						'slug'  => 'primary',
						'color' => self::hsl_hex( 'default' === get_theme_mod( 'primary_color' ) ? 199 : get_theme_mod( 'primary_color_hue', 199 ), 100, 33 ),
					),
					array(
						'name'  => esc_html__( 'Secondary', 'funiter' ),
						'slug'  => 'secondary',
						'color' => self::hsl_hex( 'default' === get_theme_mod( 'primary_color' ) ? 199 : get_theme_mod( 'primary_color_hue', 199 ), 100, 23 ),
					),
					array(
						'name'  => esc_html__( 'Dark Gray', 'funiter' ),
						'slug'  => 'dark-gray',
						'color' => '#111',
					),
					array(
						'name'  => esc_html__( 'Light Gray', 'funiter' ),
						'slug'  => 'light-gray',
						'color' => '#767676',
					),
					array(
						'name'  => esc_html__( 'White', 'funiter' ),
						'slug'  => 'white',
						'color' => '#FFF',
					),
				)
			);
			
			// Add support for responsive embedded content.
			add_theme_support( 'responsive-embeds' );
			
			
			if ( class_exists( 'WooCommerce' ) ) {
				/*Support woocommerce*/
				add_theme_support( 'woocommerce' );
				add_theme_support( 'wc-product-gallery-lightbox' );
				add_theme_support( 'wc-product-gallery-slider' );
				add_theme_support( 'wc-product-gallery-zoom' );
			}
		}
		
		public function nomos_move_comment_field_to_bottom( $fields ) {
			$comment_field = $fields['comment'];
			unset( $fields['comment'] );
			$fields['comment'] = $comment_field;
			
			return $fields;
		}
		
		/**
		 * Convert HSL to HEX colors
		 *
		 * @param      $h
		 * @param      $s
		 * @param      $l
		 * @param bool $to_hex
		 *
		 * @return string
		 */
		public static function hsl_hex( $h, $s, $l, $to_hex = true ) {
			
			$h /= 360;
			$s /= 100;
			$l /= 100;
			
			$r = $l;
			$g = $l;
			$b = $l;
			$v = ( $l <= 0.5 ) ? ( $l * ( 1.0 + $s ) ) : ( $l + $s - $l * $s );
			if ( $v > 0 ) {
				$m;
				$sv;
				$sextant;
				$fract;
				$vsf;
				$mid1;
				$mid2;
				
				$m       = $l + $l - $v;
				$sv      = ( $v - $m ) / $v;
				$h       *= 6.0;
				$sextant = floor( $h );
				$fract   = $h - $sextant;
				$vsf     = $v * $sv * $fract;
				$mid1    = $m + $vsf;
				$mid2    = $v - $vsf;
				
				switch ( $sextant ) {
					case 0:
						$r = $v;
						$g = $mid1;
						$b = $m;
						break;
					case 1:
						$r = $mid2;
						$g = $v;
						$b = $m;
						break;
					case 2:
						$r = $m;
						$g = $v;
						$b = $mid1;
						break;
					case 3:
						$r = $m;
						$g = $mid2;
						$b = $v;
						break;
					case 4:
						$r = $mid1;
						$g = $m;
						$b = $v;
						break;
					case 5:
						$r = $v;
						$g = $m;
						$b = $mid2;
						break;
				}
			}
			$r = round( $r * 255, 0 );
			$g = round( $g * 255, 0 );
			$b = round( $b * 255, 0 );
			
			if ( $to_hex ) {
				
				$r = ( $r < 15 ) ? '0' . dechex( $r ) : dechex( $r );
				$g = ( $g < 15 ) ? '0' . dechex( $g ) : dechex( $g );
				$b = ( $b < 15 ) ? '0' . dechex( $b ) : dechex( $b );
				
				return "#$r$g$b";
				
			} else {
				
				return "rgb($r, $g, $b)";
			}
		}
		
		/**
		 * Register widget area.
		 *
		 * @since nomos 1.0
		 *
		 * @link  https://codex.wordpress.org/Function_Reference/register_sidebar
		 */
		function widgets_init() {
			register_sidebar( array(
				                  'name'          => nomos_esc_text_html( 'Primary Sidebar', 'nomos' ),
				                  'id'            => 'sidebar-1',
				                  'description'   => nomos_esc_text_html( 'Add widgets here to appear in your sidebar.', 'nomos' ),
				                  'before_widget' => '<div id="%1$s" class="widget %2$s">',
				                  'after_widget'  => '</div>',
				                  'before_title'  => '<h2 class="widgettitle">',
				                  'after_title'   => '<span class="arow"></span></h2>',
			                  )
			);
			register_sidebar( array(
				                  'name'          => nomos_esc_text_html( 'Shop Sidebar', 'nomos' ),
				                  'id'            => 'shop-widget-area',
				                  'description'   => nomos_esc_text_html( 'Add widgets here to appear in your sidebar.', 'nomos' ),
				                  'before_widget' => '<div id="%1$s" class="widget %2$s">',
				                  'after_widget'  => '</div>',
				                  'before_title'  => '<h2 class="widgettitle">',
				                  'after_title'   => '<span class="arow"></span></h2>',
			                  )
			);
			register_sidebar( array(
				                  'name'          => nomos_esc_text_html( 'Product Sidebar', 'nomos' ),
				                  'id'            => 'product-widget-area',
				                  'description'   => nomos_esc_text_html( 'Add widgets here to appear in your sidebar.', 'nomos' ),
				                  'before_widget' => '<div id="%1$s" class="widget %2$s">',
				                  'after_widget'  => '</div>',
				                  'before_title'  => '<h2 class="widgettitle">',
				                  'after_title'   => '<span class="arow"></span></h2>',
			                  )
			);
		}
		
		/*Load Google fonts*/
		
		function google_fonts_url() {
			
			$font_families   = array();
			$font_families[] = 'Open+Sans:300,300i,400,400i,600,600i,700,700i,800,800i';
			$font_families[] = 'Montserrat:400,500,600,700';
			
			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);
			$fonts_url  = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
			
			return esc_url_raw( $fonts_url );
		}
		
		/**
		 * Enqueue scripts and styles.
		 *
		 * @since nomos 1.0
		 */
		function scripts() {
			if ( class_exists( 'WooCommerce' ) ) {
				if ( ! is_woocommerce() && ! is_cart() && ! is_checkout() ) {
					wp_dequeue_script( 'wc_price_slider' );
					wp_dequeue_script( 'wc-checkout' );
					wp_dequeue_script( 'wc-cart' );
					wp_dequeue_script( 'wc-chosen' );
					wp_dequeue_script( 'prettyPhoto' );
					wp_dequeue_script( 'prettyPhoto-init' );
					wp_dequeue_script( 'jquery-blockui' );
					wp_dequeue_script( 'jquery-placeholder' );
					wp_dequeue_script( 'fancybox' );
					wp_dequeue_script( 'jqueryui' );
				}
			}
			
			// Load fonts
			wp_enqueue_style( 'nomos-googlefonts', $this->google_fonts_url(), array(), false );
			
			/*Load our main stylesheet.*/
			wp_enqueue_style( 'boostrap', get_theme_file_uri( '/assets/css/bootstrap.min.css' ), array(), false );
			wp_enqueue_style( 'owl-carousel', get_theme_file_uri( '/assets/css/owl.carousel.min.css' ), array(), false );
			wp_enqueue_style( 'font-awesome', get_theme_file_uri( '/assets/css/font-awesome.min.css' ), array(), false );
			wp_enqueue_style( 'simple-line-icons', get_theme_file_uri( '/assets/css/simple-line-icons.css' ), array(), false );
			wp_enqueue_style( 'flat-icons', get_theme_file_uri( '/assets/css/flaticon.css' ), array(), false );
			wp_enqueue_style( 'scrollbar', get_theme_file_uri( '/assets/css/jquery.scrollbar.css' ), array(), false );
			wp_enqueue_style( 'nomos-custom', get_theme_file_uri( '/assets/css/customs.css' ), array(), false );
			wp_enqueue_style( 'nomos-main-style', get_theme_file_uri( '/style.css' ), array(), false );
			
//			if ( is_rtl() ) {
//				wp_enqueue_style( 'nomos-rtl', get_theme_file_uri( '/rtl.css' ), array(), false );
//			}
			
			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
				wp_enqueue_script( 'comment-reply' );
			}
			
			/*Load lib js*/
			wp_enqueue_script( 'imagesloaded' );
			wp_enqueue_script( 'wc-add-to-cart-variation' );
			wp_enqueue_script( 'bootstrap', get_theme_file_uri( '/assets/js/bootstrap.min.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'owl-carousel', get_theme_file_uri( '/assets/js/owl.carousel.min.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'chosen', get_theme_file_uri( '/assets/js/chosen.jquery.min.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'magnific-popup', get_theme_file_uri( '/assets/js/jquery.magnific-popup.min.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'scrollbar', get_theme_file_uri( '/assets/js/jquery.scrollbar.min.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'sticky', get_theme_file_uri( '/assets/js/jquery.sticky.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'full-page', get_theme_file_uri( '/assets/js/jquery.fullPage.min.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'jquery-countdown', get_theme_file_uri( '/assets/js/jquery.countdown.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'theia-sticky-sidebar', get_theme_file_uri( '/assets/js/theia-sticky-sidebar.min.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'threesixty', get_theme_file_uri( '/assets/js/threesixty.min.js' ), array( 'jquery' ), false );
			wp_enqueue_script( 'slick', get_theme_file_uri( '/assets/js/slick.js' ), array( 'jquery' ), false );
			
			$gmap_api_key = nomos_get_option( 'gmap_api_key', '' );
			$gmap_api_key = trim( $gmap_api_key );
			if ( $gmap_api_key != '' ) {
				$load_gmap_js        = false;
				$load_gmap_js_target = nomos_get_option( 'load_gmap_js_target', 'all_pages' );
				if ( $load_gmap_js_target == 'selected_pages' ) {
					$load_gmap_js_on = nomos_get_option( 'load_gmap_js_on', array() );
					if ( ! is_array( $load_gmap_js_on ) ) {
						$load_gmap_js_on = array();
					}
					if ( is_singular( 'page' ) ) {
						if ( in_array( get_the_ID(), $load_gmap_js_on ) ) {
							$load_gmap_js = true;
						}
					}
				}
				if ( $load_gmap_js_target == 'all_pages' ) {
					$load_gmap_js = true;
				}
				if ( $load_gmap_js ) {
					wp_enqueue_script( 'maps', esc_url( 'https://maps.googleapis.com/maps/api/js?key=' . $gmap_api_key ), array( 'jquery' ), false, true );
				}
			}
			
			$enable_lazy = nomos_get_option( 'nomos_enable_lazy', false );
			if ( $enable_lazy ) {
				/* http://jquery.eisbehr.de/lazy */
				wp_enqueue_script( 'lazy', get_theme_file_uri( '/assets/js/jquery.lazy.min.js' ), array( 'jquery' ), false );
			}
			
			$enable_smooth_scroll = nomos_get_option( 'enable_smooth_scroll', false );
			if ( $enable_smooth_scroll ) {
				wp_enqueue_script( 'smooth-scroll', get_theme_file_uri( '/assets/js/SmoothScroll.min.js' ), array( 'jquery' ), false );
			}
			
			wp_enqueue_script( 'nomos-script', get_theme_file_uri( '/assets/js/functions.js' ), array(), false, true );
			
			$main_menu_res_break_point = intval( nomos_get_option( 'main_menu_res_break_point', 1199 ) );
			wp_localize_script( 'nomos-script', 'nomos_theme_frontend',
			                    array(
				                    'ajaxurl'               => admin_url( 'admin-ajax.php' ),
				                    'security'              => wp_create_nonce( 'nomos_ajax_frontend' ),
				                    'main_menu_break_point' => $main_menu_res_break_point,
				                    'text'                  => array(
					                    'load_more'       => nomos_esc_text_html( 'Load More', 'nomos' ),
					                    'no_more_product' => nomos_esc_text_html( 'No More Product', 'nomos' ),
					                    'more_detail'     => nomos_esc_text_html( 'More Details', 'nomos' ),
					                    'less_detail'     => nomos_esc_text_html( 'Less Details', 'nomos' )
				                    )
			                    )
			);
			
		}
		
		/**
		 * Filter whether comments are open for a given post type.
		 *
		 * @param string $status       Default status for the given post type,
		 *                             either 'open' or 'closed'.
		 * @param string $post_type    Post type. Default is `post`.
		 * @param string $comment_type Type of comment. Default is `comment`.
		 *
		 * @return string (Maybe) filtered default status for the given post type.
		 */
		function open_default_comments_for_page( $status, $post_type, $comment_type ) {
			if ( 'page' == $post_type ) {
				return 'open';
			}
			
			return $status;
			/*You could be more specific here for different comment types if desired*/
		}
		
		
		public function includes() {
			include_once( get_template_directory() . '/framework/framework.php' );
			define( 'CS_ACTIVE_FRAMEWORK', true ); // default true
			define( 'CS_ACTIVE_METABOX', true ); // default true
			define( 'CS_ACTIVE_TAXONOMY', true ); // default true
			define( 'CS_ACTIVE_SHORTCODE', false ); // default true
			define( 'CS_ACTIVE_CUSTOMIZE', false ); // default true
		}
		
		public function nomos_custom_data_js() {
			$data = array();
			// Get option for permalink
			$data['permalink'] = ( get_option( 'permalink_structure' ) == '' ) ? 'plain' : '';
			
			return $data;
		}
		
	}
	
	new  Nomos_Functions();
}

if ( ! function_exists( 'nomos_preload_tmp' ) ) {
	function nomos_preload_tmp( $page_selector = '' ) {
		
		$html_header_tmp = '<div data-h="84" class="header-preload-wrap preload-group">
								<div class="row">
									<div class="col-md-2 col-sm-2">
										<div class="preload-div"></div>
									</div>
									<div class="col-sm-7 col-md-8">
										<div class="preload-div"></div>
									</div>
									<div class="col-sm-3 col-md-2">
										<div class="preload-div"></div>
									</div>
								</div>
							</div>';
		$html_body_tmp   = '<div class="header-preload-wrap preload-group">
								<div class="text-center">
									<div data-h="50" data-w="110" class="preload-div clear-both"></div>
									<div data-h="32" data-w="120" class="preload-div clear-both"></div>
								</div>
							</div>';
		$html_footer_tmp = '';
		$html_tmp        = '';
		
		switch ( $page_selector ) {
			case 'button-viewcart':
				$html_body_tmp = '<div class="header-preload-wrap preload-group">
										<div class="text-center">
											<div data-h="50" data-w="110" class="preload-div clear-both"></div>
											<div data-h="32" data-w="120" class="preload-div clear-both"></div>
										</div>
									</div>';
				break;
			default:
				break;
		}
		
		$html_tmp = '<div class="preload-for-' . esc_attr( $page_selector ) . ' preload-total-wrap">' . $html_header_tmp . $html_body_tmp . $html_footer_tmp . '</div>';
		
		return $html_tmp;
	}
}

if ( ! function_exists( 'nomos_html_output' ) ) {
	function nomos_html_output( $html ) {
		if ( function_exists( 'fami_wp_html_compression_output' ) ) {
			return $html;
			// return fami_wp_html_compression_output( $html );
		}
		
		return apply_filters( 'nomos_html_output', $html );
	}
}