<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link    https://codex.wordpress.org/Template_Hierarchy
 *
 * @package nomos
 */
?>
<?php get_header(); ?>
<?php

$nomos_blog_used_sidebar = nomos_get_option( 'blog_sidebar', 'widget-area' );

/* Blog Layout */
$nomos_blog_layout = nomos_get_option( 'sidebar_blog_layout', 'full' );
if ( ! is_active_sidebar( $nomos_blog_used_sidebar ) ) {
	$nomos_blog_layout = 'full';
}

/* Blog Style */
$nomos_blog_style = nomos_get_option( 'blog-style', 'standard' );

if ( $nomos_blog_layout == 'full' ) {
	$nomos_container_class[] = 'blog-page no-sidebar ' . $nomos_blog_style;
} else {
	$nomos_container_class[] = $nomos_blog_layout . '-sidebar has-sidebar';
}
$nomos_content_class   = array();
$nomos_content_class[] = 'main-content';
if ( $nomos_blog_layout == 'full' ) {
	$nomos_content_class[] = 'col-lg-12 col-md-12 col-sm-12 col-xs-12';
} else {
	$nomos_content_class[] = 'col-lg-9 col-md-9 col-sm-8 col-xs-12';
}

$nomos_slidebar_class   = array();
$nomos_slidebar_class[] = 'sidebar';
if ( $nomos_blog_layout != 'full' ) {
	$nomos_slidebar_class[] = 'col-lg-3 col-md-3 col-sm-4 col-xs-12';
}

?>
<div class="<?php echo esc_attr( implode( ' ', $nomos_container_class ) ); ?>">
    <div class="container">
		<?php if ( is_search() ) : ?>
            <header class="page-header">
				<?php if ( have_posts() ) : ?>
                    <h1 class="page-title"><?php printf( nomos_esc_text_html( 'Search Results for: %s', 'nomos' ), '<span>' . get_search_query() . '</span>' ); ?></h1>
				<?php else : ?>
                    <h1 class="page-title"><?php echo nomos_esc_text_html( 'Nothing Found', 'nomos' ); ?></h1>
				<?php endif; ?>
            </header><!-- .page-header -->
		<?php endif; ?>
        <div class="row">
            <div class="<?php echo esc_attr( implode( ' ', $nomos_content_class ) ); ?>">
				<?php get_template_part( 'templates/blog/blog', $nomos_blog_style ); ?>
            </div>
			<?php if ( $nomos_blog_layout != "full" ): ?>
                <div class="<?php echo esc_attr( implode( ' ', $nomos_slidebar_class ) ); ?>">
					<?php get_sidebar(); ?>
                </div>
			<?php endif; ?>
        </div>
    </div>
</div>
<?php get_footer(); ?>
